==> jc-1.4.0.tar.gz: soot/dava/internal/SET/SETNodeLabel.h <==
// public class soot.dava.internal.SET.SETNodeLabel

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 214a8e2f9d3c2187 soot_dava_internal_SET_SETNodeLabel

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_dava_internal_SET_SETNodeLabel_H_
#define _JC_soot_dava_internal_SET_SETNodeLabel_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_dava_internal_SET_SETNodeLabel$sub_refs	_jc_soot_dava_internal_SET_SETNodeLabel$sub_refs;
typedef struct _jc_soot_dava_internal_SET_SETNodeLabel$sub_nonrefs	_jc_soot_dava_internal_SET_SETNodeLabel$sub_nonrefs;
typedef struct _jc_soot_dava_internal_SET_SETNodeLabel$refs	_jc_soot_dava_internal_SET_SETNodeLabel$refs;
typedef struct _jc_soot_dava_internal_SET_SETNodeLabel$nonrefs	_jc_soot_dava_internal_SET_SETNodeLabel$nonrefs;
typedef struct _jc_soot_dava_internal_SET_SETNodeLabel$object	_jc_soot_dava_internal_SET_SETNodeLabel$object;

typedef const struct _jc_soot_dava_internal_SET_SETNodeLabel$vmethods	_jc_soot_dava_internal_SET_SETNodeLabel$vmethods;
typedef const struct _jc_soot_dava_internal_SET_SETNodeLabel$vtable	_jc_soot_dava_internal_SET_SETNodeLabel$vtable;
typedef const struct _jc_soot_dava_internal_SET_SETNodeLabel$vtype	_jc_soot_dava_internal_SET_SETNodeLabel$vtype;

// Constructors
extern void _jc_soot_dava_internal_SET_SETNodeLabel$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_dava_internal_SET_SETNodeLabel$object *);

// Virtual methods
extern void _jc_soot_dava_internal_SET_SETNodeLabel$method$clear__5fName$7e88ae3c90e27be5(_jc_env *, struct _jc_soot_dava_internal_SET_SETNodeLabel$object *);
extern void _jc_soot_dava_internal_SET_SETNodeLabel$method$set__5fName$84eec782dab3ee39(_jc_env *, struct _jc_soot_dava_internal_SET_SETNodeLabel$object *);
extern void _jc_soot_dava_internal_SET_SETNodeLabel$method$set__5fName$54cf712b6e6974e2(_jc_env *, struct _jc_soot_dava_internal_SET_SETNodeLabel$object *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_String$object *_jc_soot_dava_internal_SET_SETNodeLabel$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_dava_internal_SET_SETNodeLabel$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_SET_SETNodeLabel$method_info$clear__5fName$7e88ae3c90e27be5;
extern _jc_method _jc_soot_dava_internal_SET_SETNodeLabel$method_info$set__5fName$84eec782dab3ee39;
extern _jc_method _jc_soot_dava_internal_SET_SETNodeLabel$method_info$set__5fName$54cf712b6e6974e2;
extern _jc_method _jc_soot_dava_internal_SET_SETNodeLabel$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_dava_internal_SET_SETNodeLabel$vmethods {
	void	(*clear__5fName$7e88ae3c90e27be5)(_jc_env *, struct _jc_soot_dava_internal_SET_SETNodeLabel$object *);
	void	(*set__5fName$84eec782dab3ee39)(_jc_env *, struct _jc_soot_dava_internal_SET_SETNodeLabel$object *);
	void	(*set__5fName$54cf712b6e6974e2)(_jc_env *, struct _jc_soot_dava_internal_SET_SETNodeLabel$object *, struct _jc_java_lang_String$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_dava_internal_SET_SETNodeLabel$object *);
};

// Vtable
struct _jc_soot_dava_internal_SET_SETNodeLabel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_internal_SET_SETNodeLabel$vmethods	soot_dava_internal_SET_SETNodeLabel;
};

// Vtype
struct _jc_soot_dava_internal_SET_SETNodeLabel$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_SET_SETNodeLabel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_SET_SETNodeLabel$sub_refs {
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_SET_SETNodeLabel$refs {
    _jc_soot_dava_internal_SET_SETNodeLabel$sub_refs	soot_dava_internal_SET_SETNodeLabel;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_SET_SETNodeLabel$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_SET_SETNodeLabel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_internal_SET_SETNodeLabel$sub_nonrefs	soot_dava_internal_SET_SETNodeLabel;
};

// Object instance structure
struct _jc_soot_dava_internal_SET_SETNodeLabel$object {
	_jc_soot_dava_internal_SET_SETNodeLabel$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_SET_SETNodeLabel$vtype	*vtype;
	_jc_soot_dava_internal_SET_SETNodeLabel$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_SET_SETNodeLabel$vtype _jc_soot_dava_internal_SET_SETNodeLabel$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_SET_SETNodeLabel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_SET_SETNodeLabel$class_object;

#endif	/* _JC_soot_dava_internal_SET_SETNodeLabel_H_ */

==> jc-1.4.6.tar.gz: soot/dava/internal/SET/SETNodeLabel.h <==
// public class soot.dava.internal.SET.SETNodeLabel

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 214a8e2f9d3c2187 soot_dava_internal_SET_SETNodeLabel

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_dava_internal_SET_SETNodeLabel_H_
#define _JC_soot_dava_internal_SET_SETNodeLabel_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_dava_internal_SET_SETNodeLabel$sub_refs	_jc_soot_dava_internal_SET_SETNodeLabel$sub_refs;
typedef struct _jc_soot_dava_internal_SET_SETNodeLabel$sub_nonrefs	_jc_soot_dava_internal_SET_SETNodeLabel$sub_nonrefs;
typedef struct _jc_soot_dava_internal_SET_SETNodeLabel$refs	_jc_soot_dava_internal_SET_SETNodeLabel$refs;
typedef struct _jc_soot_dava_internal_SET_SETNodeLabel$nonrefs	_jc_soot_dava_internal_SET_SETNodeLabel$nonrefs;
typedef struct _jc_soot_dava_internal_SET_SETNodeLabel$object	_jc_soot_dava_internal_SET_SETNodeLabel$object;

typedef const struct _jc_soot_dava_internal_SET_SETNodeLabel$vmethods	_jc_soot_dava_internal_SET_SETNodeLabel$vmethods;
typedef const struct _jc_soot_dava_internal_SET_SETNodeLabel$vtable	_jc_soot_dava_internal_SET_SETNodeLabel$vtable;
typedef const struct _jc_soot_dava_internal_SET_SETNodeLabel$vtype	_jc_soot_dava_internal_SET_SETNodeLabel$vtype;

// Constructors
extern void _jc_soot_dava_internal_SET_SETNodeLabel$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_dava_internal_SET_SETNodeLabel$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_dava_internal_SET_SETNodeLabel$method$clear__5fName$7e88ae3c90e27be5(_jc_env *, struct _jc_soot_dava_internal_SET_SETNodeLabel$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_internal_SET_SETNodeLabel$method$set__5fName$84eec782dab3ee39(_jc_env *, struct _jc_soot_dava_internal_SET_SETNodeLabel$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_internal_SET_SETNodeLabel$method$set__5fName$54cf712b6e6974e2(_jc_env *, struct _jc_soot_dava_internal_SET_SETNodeLabel$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_dava_internal_SET_SETNodeLabel$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_dava_internal_SET_SETNodeLabel$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_SET_SETNodeLabel$method_info$clear__5fName$7e88ae3c90e27be5;
extern _jc_method _jc_soot_dava_internal_SET_SETNodeLabel$method_info$set__5fName$84eec782dab3ee39;
extern _jc_method _jc_soot_dava_internal_SET_SETNodeLabel$method_info$set__5fName$54cf712b6e6974e2;
extern _jc_method _jc_soot_dava_internal_SET_SETNodeLabel$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_dava_internal_SET_SETNodeLabel$vmethods {
	void	(*clear__5fName$7e88ae3c90e27be5)(_jc_env *, struct _jc_soot_dava_internal_SET_SETNodeLabel$object *) _JC_JCNI_ATTR;
	void	(*set__5fName$84eec782dab3ee39)(_jc_env *, struct _jc_soot_dava_internal_SET_SETNodeLabel$object *) _JC_JCNI_ATTR;
	void	(*set__5fName$54cf712b6e6974e2)(_jc_env *, struct _jc_soot_dava_internal_SET_SETNodeLabel$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_dava_internal_SET_SETNodeLabel$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_internal_SET_SETNodeLabel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_internal_SET_SETNodeLabel$vmethods	soot_dava_internal_SET_SETNodeLabel;
};

// Vtype
struct _jc_soot_dava_internal_SET_SETNodeLabel$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_SET_SETNodeLabel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_SET_SETNodeLabel$sub_refs {
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_SET_SETNodeLabel$refs {
    _jc_soot_dava_internal_SET_SETNodeLabel$sub_refs	soot_dava_internal_SET_SETNodeLabel;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_SET_SETNodeLabel$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_SET_SETNodeLabel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_internal_SET_SETNodeLabel$sub_nonrefs	soot_dava_internal_SET_SETNodeLabel;
};

// Object instance structure
struct _jc_soot_dava_internal_SET_SETNodeLabel$object {
	_jc_soot_dava_internal_SET_SETNodeLabel$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_SET_SETNodeLabel$vtype	*vtype;
	_jc_soot_dava_internal_SET_SETNodeLabel$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_SET_SETNodeLabel$vtype _jc_soot_dava_internal_SET_SETNodeLabel$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_SET_SETNodeLabel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_SET_SETNodeLabel$class_object;

#endif	/* _JC_soot_dava_internal_SET_SETNodeLabel_H_ */
